// 
// Copyright (c) 2013-2017 Carsten Sonne Larsen <cs@innolan.net>
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System.Collections.Generic;

namespace Ntp.Analyzer.Data.Import
{
    public static class TimeServers
    {
        public static readonly Dictionary<string, int> List = new Dictionary<string, int>
        {
            {"128.4.40.12", 1},
            {"128.4.1.2", 2},
            {"time1.one4vision.de", 3},
            {"time2.one4vision.de", 4},
            {"212.82.32.26", 4},
            {"time.sinectis.com.ar", 6},
            {"tick.nap.com.ar", 7},
            {"ntp2.phoenixpubliclibrary.org", 8},
            {"148.167.132.201", 8},
            {"ntp1.phoenixpubliclibrary.org", 9},
            {"148.167.132.200", 9},
            {"ntp.drydog.com", 10},
            {"216.218.196.162", 10},
            {"2001:470:1:3cd::2", 10},
            {"216.218.192.202", 11},
            {"200.49.40.15", 12},
            {"195.13.23.5", 14},
            {"195.13.1.153", 15},
            {"200.144.121.33", 16},
            {"ntp.hiway.com.br", 17},
            {"200.137.65.132", 19},
            {"ntp.cpsc.ucalgary.ca", 21},
            {"136.159.2.4", 21},
            {"136.159.2.1", 21},
            {"ntp1.theremailer.net", 27},
            {"ntp1v6.theremailer.net", 27},
            {"85.10.240.253", 27},
            {"2a01:4f8:141:282::5:3", 27},
            {"time.deu.edu.tr", 28},
            {"blade.avnf.com", 29},
            {"ntp.pads.ufrj.br", 30},
            {"146.164.48.1", 30},
            {"2001:1291:200:8371::1", 30},
            {"b.ntp.setilabs.net", 35},
            {"a.ntp.setilabs.net", 36},
            {"200.254.135.2", 37},
            {"ntp1.cmc.ec.gc.ca", 38},
            {"ntp2.cmc.ec.gc.ca", 39},
            {"205.189.10.22", 39},
            {"time.chu.nrc.ca", 41},
            {"209.87.233.53", 41},
            {"time.nrc.ca", 42},
            {"132.246.11.238", 42},
            {"132.246.11.229", 42},
            {"132.246.11.227", 42},
            {"142.3.100.15", 43},
            {"ntp.cgi.cz", 45},
            {"178.238.36.117", 45},
            {"ntp.globe.cz", 46},
            {"81.95.103.173", 46},
            {"ntp1.contactel.cz", 48},
            {"ntp2.contactel.cz", 49},
            {"hora.oxixares.com", 53},
            {"37.187.170.220", 53},
            {"194.179.52.14", 54},
            {"tick.keso.fi", 55},
            {"tock.keso.fi", 56},
            {"ntp.obspm.fr", 58},
            {"145.238.203.10", 58},
            {"138.195.130.71", 63},
            {"ntp.mfa.gr", 64},
            {"195.167.30.249", 64},
            {"2a02:587:8f0::224:0:20", 64},
            {"os.ntp.carnet.hr", 66},
            {"161.53.30.104", 66},
            {"ri.ntp.carnet.hr", 67},
            {"161.53.30.170", 67},
            {"st.ntp.carnet.hr", 68},
            {"161.53.30.50", 68},
            {"zg1.ntp.carnet.hr", 69},
            {"161.53.123.5", 69},
            {"2001:b68:ff:2::5", 69},
            {"zg2.ntp.carnet.hr", 70},
            {"161.53.160.5", 70},
            {"2001:b68:ff:1::5", 70},
            {"time.kfki.hu", 71},
            {"148.6.0.1", 71},
            {"2001:738:5001::1", 71},
            {"202.180.0.71", 72},
            {"ntp.maths.tcd.ie", 73},
            {"134.226.81.3", 73},
            {"2001:770:10:300::86e2:5103", 73},
            {"ntp.supernet300.com", 79},
            {"ntp1.theinternetone.net", 80},
            {"ntp2.theinternetone.net", 81},
            {"ntp3.theinternetone.net", 82},
            {"129.240.64.3", 83},
            {"ntp.iprolink.co.nz", 85},
            {"203.152.107.68", 85},
            {"203.152.107.67", 85},
            {"ntp.massey.ac.nz", 86},
            {"130.123.104.69", 86},
            {"130.123.96.70", 86},
            {"130.123.108.7", 86},
            {"ntp.public.otago.ac.nz", 87},
            {"139.80.64.114", 87},
            {"tk1.ihug.co.nz", 88},
            {"tk2.ihug.co.nz", 89},
            {"tk3.ihug.co.nz", 90},
            {"203.109.129.1", 90},
            {"ntp.psn.ru", 94},
            {"194.149.67.129", 94},
            {"time.flygplats.net", 97},
            {"213.114.130.250", 97},
            {"ntp1.arnes.si", 100},
            {"193.2.1.117", 100},
            {"2001:1470:8000::117", 100},
            {"ntp2.arnes.si", 101},
            {"193.2.1.92", 101},
            {"2001:1470:8000::92", 101},
            {"168.243.7.66", 103},
            {"ntp.exnet.com", 106},
            {"79.135.97.70", 106},
            {"ntp2c.mcc.ac.uk", 109},
            {"130.88.200.6", 109},
            {"ntp2d.mcc.ac.uk", 110},
            {"130.88.212.143", 110},
            {"194.164.127.5", 111},
            {"194.164.127.4", 112},
            {"194.164.127.6", 113},
            {"158.43.128.66", 115},
            {"195.112.34.51", 117},
            {"time.cachenetworks.com", 119},
            {"69.22.157.2", 119},
            {"69.31.3.3", 119},
            {"216.218.254.202", 120},
            {"132.239.254.49", 121},
            {"ntp2.mainecoon.com", 123},
            {"192.83.249.28", 124},
            {"204.74.68.55", 125},
            {"reloj.kjsl.com", 126},
            {"198.137.202.60", 126},
            {"2001:1868:a100:131::60", 126},
            {"time.berkeley.netdot.net", 127},
            {"ntp1.linuxmedialabs.com", 129},
            {"96.47.0.50", 129},
            {"rolex.usg.edu", 132},
            {"198.72.72.10", 132},
            {"ntp-0.cso.uiuc.edu", 134},
            {"130.126.24.53", 134},
            {"2620::e00:4012:0:0:0:2", 134},
            {"ntp-1.cso.uiuc.edu", 135},
            {"130.126.24.24", 135},
            {"2620::e00:4010:0:0:0:2", 135},
            {"ntp-2.cso.uiuc.edu", 136},
            {"130.126.24.44", 136},
            {"2620::e00:4011:0:0:0:2", 136},
            {"199.240.130.12", 145},
            {"199.240.130.1", 146},
            {"128.101.101.101", 148},
            {"134.84.84.84", 149},
            {"chronos1.umt.edu", 151},
            {"192.73.48.1", 151},
            {"chronos2.umt.edu", 152},
            {"192.73.48.2", 152},
            {"chronos3.umt.edu", 153},
            {"192.73.48.6", 153},
            {"152.2.21.1", 154},
            {"ntp.uhfradio.com", 155},
            {"tick.jrc.us", 156},
            {"208.90.144.52", 156},
            {"tock.jrc.us", 157},
            {"208.90.144.53", 157},
            {"131.216.22.15", 159},
            {"131.216.22.17", 160},
            {"clock.linuxshell.net", 161},
            {"209.51.161.238", 162},
            {"ntp0.cornell.edu", 163},
            {"132.236.56.250", 163},
            {"reva.ziaspace.com", 164},
            {"128.118.25.3", 170},
            {"ntp-1.cede.psu.edu", 171},
            {"ntp-2.cede.psu.edu", 172},
            {"209.144.20.76", 176},
            {"ntp.tmc.edu", 177},
            {"ntppub.tamu.edu", 178},
            {"128.194.254.9", 178},
            {"198.82.1.202", 181},
            {"198.82.1.201", 182},
            {"198.82.1.203", 183},
            {"198.82.1.204", 184},
            {"ntp1.cs.wisc.edu", 189},
            {"128.105.39.11", 189},
            {"ntp3.cs.wisc.edu", 190},
            {"128.105.37.11", 190},
            {"207.126.97.57", 191},
            {"150.188.8.196", 192},
            {"146.64.241.229", 194},
            {"ntps1.pads.ufrj.br", 199},
            {"128.233.3.100", 202},
            {"128.233.3.101", 203},
            {"ntp.metas.ch", 204},
            {"162.23.41.10", 204},
            {"146.83.8.200", 206},
            {"200.54.149.19", 207},
            {"ntp0.fau.de", 209},
            {"131.188.3.220", 209},
            {"ntp1.fau.de", 210},
            {"131.188.3.221", 210},
            {"ntp2.fau.de", 211},
            {"131.188.3.222", 211},
            {"ntp3.fau.de", 212},
            {"131.188.3.223", 212},
            {"ntps1-0.eecsit.tu-berlin.de", 213},
            {"130.149.17.21", 213},
            {"ntps1-1.eecsit.tu-berlin.de", 214},
            {"130.149.17.8", 214},
            {"ptbtime1.ptb.de", 215},
            {"192.53.103.108", 215},
            {"ptbtime2.ptb.de", 216},
            {"192.53.103.104", 216},
            {"129.69.1.153", 217},
            {"ntp-galway.hea.net", 228},
            {"140.203.204.77", 228},
            {"133.100.9.2", 230},
            {"133.100.11.8", 231},
            {"193.67.79.202", 233},
            {"193.79.237.14", 235},
            {"193.79.237.30", 237},
            {"ntp.certum.pl", 242},
            {"213.222.200.99", 242},
            {"150.254.183.15", 243},
            {"ntp1.gbg.netnod.se", 244},
            {"gbg1.ntp.se", 244},
            {"192.36.133.17", 244},
            {"194.58.203.20", 244},
            {"ntp2.gbg.netnod.se", 245},
            {"gbg2.ntp.se", 245},
            {"192.36.133.66", 245},
            {"194.58.203.148", 245},
            {"ntp1.mmo.netnod.se", 246},
            {"mmo1.ntp.se", 246},
            {"192.36.134.17", 246},
            {"194.58.204.20", 246},
            {"ntp2.mmo.netnod.se", 247},
            {"mmo2.ntp.se", 247},
            {"192.36.134.25", 247},
            {"194.58.204.148", 247},
            {"ntp1.sp.se", 248},
            {"62.119.40.98", 248},
            {"193.11.166.8", 248},
            {"ntp2.sp.se", 249},
            {"62.119.40.99", 249},
            {"193.11.166.20", 249},
            {"ntp1.sth.netnod.se", 250},
            {"sth1.ntp.se", 250},
            {"192.36.144.22", 250},
            {"194.58.202.20", 250},
            {"ntp2.sth.netnod.se", 251},
            {"sth2.ntp.se", 251},
            {"192.36.144.23", 251},
            {"194.58.202.148", 251},
            {"time1.stupi.se", 252},
            {"192.36.143.150", 252},
            {"time2.stupi.se", 253},
            {"192.36.143.151", 253},
            {"chronos.csr.net", 256},
            {"204.123.2.5", 261},
            {"209.81.9.7", 263},
            {"207.200.81.113", 266},
            {"69.25.96.13", 267},
            {"64.125.78.85", 268},
            {"192.6.38.127", 269},
            {"128.9.176.30", 273},
            {"129.6.15.28", 277},
            {"129.6.15.29", 278},
            {"time-a.timefreq.bldrdoc.gov", 279},
            {"132.163.4.101", 279},
            {"132.163.4.102", 280},
            {"132.163.4.103", 281},
            {"192.43.244.18", 283},
            {"128.138.140.44", 284},
            {"ntp1.conectiv.com", 288},
            {"138.39.23.13", 288},
            {"128.4.1.1", 290},
            {"18.26.4.105", 296},
            {"time.keneli.org", 300},
            {"173.162.192.156", 300},
            {"152.1.58.124", 305},
            {"nist1-ny.witime.net", 307},
            {"time.xmission.com", 314},
            {"198.60.22.240", 314},
            {"2607:fa18::2407", 314},
            {"206.246.118.250", 317},
            {"time-nw.nist.gov", 318},
            {"131.107.13.100", 318},
            {"ntp.knowledge.or.id", 329},
            {"clock.develooper.com", 331},
            {"207.171.7.151", 331},
            {"207.171.7.152", 331},
            {"ntp.xland.ru", 334},
            {"ntp.remco.org", 340},
            {"83.163.209.244", 340},
            {"ntp6.remco.org", 341},
            {"t2.timegps.net", 342},
            {"69.75.229.43", 342},
            {"stdtime.gov.hk", 343},
            {"118.103.146.184", 343},
            {"ntp1.tpg.com.au", 344},
            {"203.12.160.2", 344},
            {"ntp1.vniiftri.ru", 349},
            {"89.109.251.21", 349},
            {"tick.meteonews.ch", 350},
            {"91.195.238.4", 350},
            {"tack.meteonews.net", 351},
            {"78.46.52.71", 351},
            {"2a01:4f8:101:1068::2", 351},
            {"ntp2.vniiftri.ru", 352},
            {"89.109.251.22", 352},
            {"ntp3.vniiftri.ru", 353},
            {"89.109.251.23", 353},
            {"ntp.favey.ch", 354},
            {"195.34.89.227", 354},
            {"ntp.any.ovee.net.au", 355},
            {"ntp2.oma.be", 356},
            {"193.190.230.66", 356},
            {"t1.timegps.net", 357},
            {"69.75.229.42", 357},
            {"andromeda.ziaspace.com", 358},
            {"209.36.14.133", 358},
            {"2001:470:a068:34:250:e4ff:fee0:c035", 358},
            {"tick.jpunix.net", 362},
            {"ntp21.vniiftri.ru", 363},
            {"89.109.251.25", 363},
            {"ntp.vik.bg", 365},
            {"ntp2.tpg.com.au", 366},
            {"203.26.24.6", 366},
            {"ntp1.oma.be", 367},
            {"193.190.230.65", 367},
            {"ntp.evertje.net", 369},
            {"time.it2.net", 371},
            {"ntp1.usv.ro", 372},
            {"ntp.myfloridacity.us", 373},
            {"71.40.128.146", 373},
            {"ntp1.kamino.fr", 377},
            {"68.216.79.113", 378},
            {"ntp2.usv.ro", 387},
            {"80.96.120.252", 387},
            {"2001:b30:4c02:1::a2", 387},
            {"82.96.64.2", 388},
            {"2001:1bc0::ffff:bbbb:2", 388},
            {"ntp3.usv.ro", 389},
            {"80.96.120.253", 389},
            {"2001:b30:4c02:1::a3", 389},
            {"hora.roa.es", 390},
            {"150.214.94.5", 390},
            {"ntp.vld.ru", 391},
            {"ntp.nblug.org", 392},
            {"208.201.242.2", 392},
            {"2001:470:1f05:1ae2::", 392},
            {"timelord.w1nr.net", 393},
            {"148.243.173.8", 394},
            {"ntp.ujf.cas.cz", 397},
            {"time.desynched.net", 400},
            {"ntp.prato.linux.it", 401},
            {"ntp04.oal.ul.pt", 405},
            {"194.117.9.136", 405},
            {"timehost.lysator.liu.se", 206},
            {"130.236.254.17", 406},
            {"ntp0.alterox.ro", 407},
            {"ntp.pinklemon.net", 408},
            {"109.74.206.120", 408},
            {"2a01:7e00::f03c:91ff:fe96:f129", 408},
            {"extntp0.inf.ed.ac.uk", 409},
            {"129.215.160.240", 409},
            {"extntp1.inf.ed.ac.uk", 410},
            {"129.215.42.240", 410},
            {"ntp.mostovna.com", 411},
            {"46.54.224.12", 411},
            {"ntp1.campus-rv.net", 412},
            {"193.106.144.6", 412},
            {"2a00:fc00:e000:1::6", 412},
            {"ntp.zsuatt.com", 413},
            {"time.sys.mywn.co.uk", 414},
            {"a.ntp.madduck.net", 416},
            {"188.174.253.163", 416},
            {"2001:a60:902f:123::1", 416},
            {"b.ntp.madduck.net", 417},
            {"130.60.157.243", 417},
            {"2001:470:b46d:123::1", 417},
            {"c.ntp.madduck.net", 418},
            {"77.109.139.83", 418},
            {"2001:1620:2018:2::123", 418},
            {"www.millnet.se", 422},
            {"ntp1.yellowcheese.com", 424},
            {"84.49.245.201", 426},
            {"ntp.gazduire.ro", 427},
            {"ntp.host.bg", 428},
            {"stratum2.sjc1.publicntp.net", 434},
            {"nist.expertsmi.com", 435},
            {"90.185.140.134", 438},
            {"2001:470:28:4a6::4", 438},
            {"stratum2.ord2.publicntp.net", 439},
            {"50.31.2.213", 439},
            {"gps.layer42.net", 440},
            {"69.36.224.15", 440},
            {"ntp11.metas.ch", 441},
            {"162.23.41.55", 441},
            {"ntp12.metas.ch", 442},
            {"162.23.41.56", 442},
            {"ntp1.inrim.it", 446},
            {"193.204.114.232", 446},
            {"ntp.ragingfist.net", 447},
            {"pubts0 -sj.certichron.com", 450},
            {"pubts1-sj.witime.net", 451},
            {"pubts2-sj.witime.net", 452},
            {"ntp-public.uit.no", 455},
            {"129.242.4.241", 455},
            {"ntp.nict.jp", 458},
            {"133.243.238.244", 458},
            {"133.243.238.164", 458},
            {"133.243.238.163", 458},
            {"133.243.238.243", 458},
            {"2001:df0:232:eea0::fff3", 458},
            {"2001:df0:232:eea0::fff4", 458},
            {"ntp.i2t.ehu.eus", 463},
            {"158.227.98.15", 463},
            {"2001:720:1410:101f::15", 463},
            {"ntp.nic.cz", 464},
            {"217.31.202.100", 464},
            {"2001:1488:ffff::100", 464},
            {"ntp3.time.bendig.name", 467},
            {"ntp4.time.bendig.name", 468},
            {"ntp5.time.bendig.name", 469},
            {"uk.ntp.f-box.org", 470},
            {"us.ntp.f-box.org", 471},
            {"de.ntp.f-box.org", 472},
            {"ntp.ntp-servers.com", 473},
            {"5.226.98.186", 473},
            {"ntp.bytestacker.com", 477},
            {"ntp.mazzanet.net.au", 478},
            {"ntp.dvconsulting.dk", 479},
            {"195.234.155.123", 479},
            {"ntp.gal.dk", 480},
            {"195.234.155.124", 480},
            {"tick.mtnlion.com", 481},
            {"204.13.164.164", 481},
            {"ntp.tourism.wa.gov.au", 483},
            {"time.intersecur.net", 485},
            {"ntp.ilianum.com", 486},
            {"ntp1.stsn.net", 487},
            {"ntp2.stsn.net", 488},
            {"ntp3.stsn.net", 489},
            {"ntp.kos.wsiz.rzeszow.pl", 492},
            {"nist.netservicesgroup.com", 493},
            {"64.113.32.5", 493},
            {"rtr.firmacem.ru", 494},
            {"ntp.fedoramd.org", 495},
            {"ntp.qays.net", 496},
            {"ntp.your.org", 498},
            {"204.9.54.119", 498},
            {"2001:4978:1:2:20e:feff:fe01:ac0", 498},
            {"hera.limescope.net", 500},
            {"itsuki.fkraiem.org", 501},
            {"ntp0.mao.kiev.ua", 505},
            {"ntp.home-dn.net", 506},
            {"62.210.109.229", 506},
            {"2001:bc8:3663:200::1", 506},
            {"thecavemanslan.com", 508},
            {"b.ntp.br", 509},
            {"c.ntp.br", 510},
            {"200.192.232.8", 510},
            {"a.ntp.br", 511},
            {"200.160.0.8", 511},
            {"2001:12ff::8", 511},
            {"ntp2.linocomm.net", 512},
            {"62.210.211.218", 512},
            {"2001:bc8:24c7:200::123", 512},
            {"ntp1.linocomm.net", 513},
            {"109.236.83.221", 513},
            {"2a00:7c80::d:0:0:0:123", 513},
            {"ntp.adc.am", 514},
            {"91.103.24.10", 514},
            {"ntp.eisvogel.nl", 518},
            {"ntp.dianacht.de", 520},
            {"77.37.6.59", 520},
            {"2001:4d88:1ffa:65::123", 520},
            {"ac-ntp1.net.cmu.edu", 521},
            {"128.2.1.21", 521},
            {"ac-ntp2.net.cmu.edu", 522},
            {"128.2.1.22", 522},
            {"utcnist2.colorado.edu", 524},
            {"128.138.141.172", 524},
            {"150.101.254.110", 525},
            {"ntp3.linocomm.net", 526},
            {"89.188.26.129", 526},
            {"2a01:1b0:7998:415::123", 526},
            {"nist1-la.witime.net", 529},
            {"timelordzero.shado.dyndns.info", 530},
            {"serv01.richs.nl", 531},
            {"89.16.173.64", 533},
            {"212.13.194.87", 534},
            {"2001:ba8:0:1f1:216:3eff:fe14:ae0a", 534},
            {"atom.uhr.de", 535},
            {"ntp.inode.at", 536},
            {"time.ufe.cz", 537},
            {"147.231.2.6", 537},
            {"ticktock.net.ru", 538},
            {"ntp1.dooh.ro", 540},
            {"ntp2.dooh.ro", 541},
            {"ntp01.packetscan.com", 543},
            {"ntp1.madavi.de", 545},
            {"81.169.169.173", 545},
            {"2a01:238:4244:bd00:54b7:3b77:e3ee:4e7c", 545},
            {"ntp2.madavi.de", 546},
            {"85.214.229.39", 546},
            {"ntp3.madavi.de", 547},
            {"85.214.240.94", 547},
            {"2a01:238:4202:e00:342a:970a:ad33:75fd", 547},
            {"asynchronos.iiss.at", 548},
            {"ntp.edge.tillo.ch", 549},
            {"ntp.time.in.ua", 551},
            {"62.149.0.30", 551},
            {"2a03:6300:2::123", 551},
            {"quassia.associazione-tp.it", 552},
            {"212.45.144.11", 552},
            {"tiempo.promomedios.com", 555},
            {"ntp1.netwrx1.com", 560},
            {"ntp2.netwrx1.com", 561},
            {"ntp3.netwrx1.com", 562},
            {"ntp.mya.org", 569},
            {"75.150.206.145", 569},
            {"ntp4.vniiftri.ru", 572},
            {"89.109.251.24", 572},
            {"thecraag.com", 573},
            {"ntp2.radioalfa.pl", 574},
            {"89.174.70.2", 574},
            {"ntp.au.zoidial.com", 575},
            {"time.coi.pw.edu.pl", 576},
            {"194.29.130.252", 576},
            {"ntpstm.netbone-digital.com", 577},
            {"ntp.databank.com.gr", 578},
            {"ntp.demongeot.biz", 579},
            {"194.169.214.72", 579},
            {"46.105.237.136", 579},
            {"212.83.158.83", 579},
            {"195.154.174.209", 579},
            {"5.135.188.53", 579},
            {"2001:41d0:8:c535::1", 579},
            {"2001:bc8:313f::1", 579},
            {"2001:bc8:3e85:100::1", 579},
            {"ntp1.kangran.su", 580},
            {"46.252.169.154", 580},
            {"ntp.letinet.ru", 581},
            {"95.140.94.2", 581},
            {"ntp.vc.ukrtel.net", 582},
            {"ntp.grafix.nl", 583},
            {"localh0rst.de", 585},
            {"clock.fihn.net", 588},
            {"ntp.markyate.net", 590},
            {"84.45.170.220", 590},
            {"2001:4d48:ad51:2b03::da7e", 590},
            {"ntp2.idsi.md", 591},
            {"193.226.65.2", 591},
            {"time.edv-froehlich.de", 592},
            {"62.113.203.99", 592},
            {"185.133.72.100", 592},
            {"130.255.78.223", 592},
            {"62.113.203.55", 592},
            {"2a05:b0c6:5e4::2", 592},
            {"2a00:f48:100c:7b::2", 592},
            {"2a00:f48:100c:7e::2", 592},
            {"2a02:e00:ffec:11a::2", 592},
            {"ntp.crifo.org", 593},
            {"212.83.134.160", 593},
            {"ts1.aco.net", 595},
            {"193.171.23.163", 595},
            {"2001:628:2030:dcf1::ac0", 595},
            {"ts2.aco.net", 596},
            {"131.130.251.107", 596},
            {"2001:62a:4:311::ac0", 596},
            {"ntp1.openbsd.se", 597},
            {"81.226.218.187", 597},
            {"ntp2.openbsd.se", 598},
            {"81.236.239.155", 598},
            {"72.14.183.239", 604},
            {"2600:3c00::e:d0bb", 604},
            {"ntp1.rueckgr.at", 607},
            {"5.9.110.236", 607},
            {"2a01:4f8:162:51e2::2", 607},
            {"gwyn.kn-bremen.de", 608},
            {"148.251.8.79", 608},
            {"tick.mattnordhoff.com", 609},
            {"45.79.1.70", 609},
            {"2600:3c00::2:b401", 609},
            {"ntp.netzwerkteufel.net", 610},
            {"ntp.wsrs.net", 611},
            {"5.200.6.34", 611},
            {"2a02:348:54:5132::1", 611},
            {"stratum2-4.ntp.techfak.uni-bielefeld.de", 614},
            {"129.70.132.33", 614},
            {"2001:638:504:2000::33", 614},
            {"ntp.idsi.md", 615},
            {"timehu.lonyai.com", 621},
            {"213.157.100.71", 621},
            {"rafi.inha.ac.kr", 622},
            {"cse.inha.ac.kr", 623},
            {"ntp1.chrisjohnston.org", 625},
            {"ntp2.chrisjohnston.org", 626},
            {"ntp.systemtid.se", 627},
            {"212.181.208.227", 627},
            {"time.envirahost.com", 628},
            {"sesku.planeacion.net", 631},
            {"148.216.0.30", 631},
            {"ntp.jentfoo.com", 632},
            {"173.203.211.73", 632},
            {"time.fu-berlin.de", 633},
            {"130.133.1.10", 633},
            {"zeit.fu-berlin.de", 634},
            {"160.45.10.8", 634},
            {"ntp.lekksi.com", 635},
            {"tick.myodn.ch", 636},
            {"ntp.exion.tillo.ch", 639},
            {"ntp1.borg-collective.org.uk", 640},
            {"82.68.133.225", 640},
            {"a.st1.ntp.br", 641},
            {"200.160.7.186", 641},
            {"2001:12ff::7:0:0:0:186", 641},
            {"c.st1.ntp.br", 642},
            {"200.186.125.195", 642},
            {"d.st1.ntp.br", 643},
            {"200.20.186.76", 643},
            {"ntp.duckcorp.org", 645},
            {"193.17.192.211", 645},
            {"2001:67c:1740:9016::c111:c0d3", 645},
            {"85.89.165.69", 646},
            {"91.215.80.69", 647},
            {"ntp.cyberinfo.se", 648},
            {"79.136.86.176", 648},
            {"2001:470:df57:2::9", 648},
            {"ntp.bsdbg.net", 649},
            {"95.87.227.232", 649},
            {"ntp.alks.org", 650},
            {"ntp.theforest.us", 652},
            {"184.73.235.44", 652},
            {"2001:470:e5a2::1", 652},
            {"clock.danplanet.com", 653},
            {"ntp1.doowan.net", 654},
            {"194.177.34.118", 654},
            {"iori.fkraiem.org", 655},
            {"ntp2.jentfoo.com", 658},
            {"184.106.219.19", 658},
            {"193.93.167.241", 660},
            {"optimusprime .64bitvps.com", 662},
            {"optimussupreme.64bitvps.com", 663},
            {"optimusprimal.64bitvps.com", 664},
            {"ntp.glorb.com", 668},
            {"204.235.61.9", 668},
            {"2607:fc18:bad:dead:beef::", 668},
            {"time.slackadelic.com", 669},
            {"ntp.amnic.net", 670},
            {"time.falk.us", 671},
            {"74.104.167.114", 671},
            {"ntp.a-lab.fi", 672},
            {"ntp.billn.net", 673},
            {"ntp.strifler.name", 674},
            {"ntp3.stratum1.ru", 675},
            {"91.226.136.141", 675},
            {"2001:470:784d:fffd::6", 675},
            {"ntp1.stratum1.ru", 676},
            {"91.226.136.138", 676},
            {"88.147.254.228", 676},
            {"2001:470:784d:fffd::4", 676},
            {"timekeeper.delphij.net", 684},
            {"64.62.153.210", 684},
            {"2001:470:1:117::2", 684},
            {"ntp.reinig-it.de", 685},
            {"144.76.20.118", 685},
            {"ntp.melancthon.net", 686},
            {"66.228.48.238", 686},
            {"ntp.squirrels.us", 687},
            {"ntp2.kangran.su", 688},
            {"89.221.207.113", 688},
            {"ntp4.stratum2.ru", 689},
            {"91.226.136.155", 689},
            {"2001:470:784d:fffd::a", 689},
            {"ntp.sonur.ru", 690},
            {"83.143.51.50", 690},
            {"193.93.167.239", 692},
            {"81.94.123.16", 695},
            {"2001:4b20::beef:1:16", 695},
            {"81.94.123.17", 696},
            {"2001:4b20::beef:1:17", 696},
            {"b.st1.ntp.br", 697},
            {"201.49.148.135", 697},
            {"gps.ntp.br", 698},
            {"200.160.7.193", 698},
            {"200.160.7.197", 698},
            {"2001:12ff::7:0:0:0:197", 698},
            {"2001:12ff::7:0:0:0:193", 698},
            {"ntp.zyhyt.org", 700},
            {"ntp.blava.net", 701},
            {"openbrick.kicks-ass.net", 704},
            {"66.114.93.6", 704},
            {"ntp.ramtek.net.tr", 706},
            {"195.149.85.1", 706},
            {"157.88.36.37", 709},
            {"ntp.baseip.com", 713},
            {"time.digibase.ca", 714},
            {"72.38.129.202", 714},
            {"fergus.myftp.org", 715},
            {"178.124.149.113", 715},
            {"ntp1.de", 716},
            {"109.95.210.143", 717},
            {"ntp.exact-time.org", 719},
            {"31.28.161.68", 719},
            {"2a03:6300:1:100::123", 719},
            {"ntp2.rueckgr.at", 721},
            {"78.47.148.174", 721},
            {"2a01:4f8:d13:885::2", 721},
            {"ntp1.inflammable.ws", 722},
            {"ntp2.inflammable.ws", 723},
            {"ntp.spbrasil.com.br", 727},
            {"ntp.baragwanath.co.za", 728},
            {"146.64.24.58", 728},
            {"time.spbrasil.com.br", 729},
            {"ntp1.bluepink.ro", 730},
            {"91.216.151.59", 730},
            {"ntp2.bluepink.ro", 731},
            {"91.216.151.61", 731},
            {"ntp3.bluepink.ro", 732},
            {"91.216.151.201", 732},
            {"ntp4.bluepink.ro", 733},
            {"ntp5.bluepink.ro", 734},
            {"91.216.151.202", 734},
            {"clock01.sctn01.burst.net", 735},
            {"clock02.sctn01.burst.net", 736},
            {"clock01.mifl01.burst.net", 737},
            {"clock02.mifl01.burst.net", 738},
            {"clock01.laca02.burst.net", 739},
            {"clock02.laca02.burst.net", 740},
            {"ntp2.aas.ru", 747},
            {"195.210.189.103", 747},
            {"ntp1.aas.ru", 748},
            {"tock.binary.net", 751},
            {"216.229.0.50", 751},
            {"tick.binary.net", 752},
            {"216.229.0.49", 752},
            {"tick.ellipse.net", 753},
            {"216.229.4.66", 753},
            {"tock.ellipse.net", 754},
            {"216.229.4.69", 754},
            {"ntp.aas.ru", 755},
            {"ntp.sceen.net", 756},
            {"151.80.19.218", 756},
            {"2001:41d0:c:ada::1", 756},
            {"ntppub.le.ac.uk", 760},
            {"143.210.16.201", 760},
            {"2001:630:306:10::c9", 760},
            {"nn.sg", 762},
            {"ntp2.de", 763},
            {"ntp1.servman.ca", 765},
            {"24.141.214.195", 765},
            {"194.190.168.1", 766},
            {"ntp.bozoncek.si.eu.org", 769},
            {"ntp2v6.unixnet.dk", 770},
            {"2001:470:1f15:175::2", 770},
            {"einstein.kenyonralph.com", 771},
            {"2600:8801:9300:1f7:222:4dff:fe83:cd4a", 771},
            {"173.255.215.209", 772},
            {"2600:3c01::f03c:91ff:fe93:b0d1", 772},
            {"ntp.hds-tech.fr", 773},
            {"ntp0.luns.net.uk", 774},
            {"217.114.59.66", 774},
            {"2a01:8900::aaaa", 774},
            {"ntp1.luns.net.uk", 775},
            {"217.114.59.3", 775},
            {"2a01:8900::1:0:0:0:aaaa", 775},
            {"tick.eoni.com", 778},
            {"216.228.192.51", 778},
            {"2607:f248::33", 778},
            {"tock.eoni.com", 779},
            {"216.228.192.52", 779},
            {"2607:f248::34", 779},
            {"ntp.ishikawa.sne.jp", 780},
            {"ntp.synet.edu.cn", 781},
            {"ntp.neu6.edu.cn", 782},
            {"202.118.1.130", 782},
            {"2001:da8:9000::130", 782},
            {"dmz0.la-archdiocese.net", 785},
            {"209.151.225.100", 785},
            {"dmz2.la-archdiocese.net", 786},
            {"205.161.200.3", 786},
            {"ntp3.servman.ca", 788},
            {"72.38.65.102", 788},
            {"ntp1.iqnet.com", 791},
            {"62.201.214.162", 791},
            {"ntp2.iqnet.com", 792},
            {"stratum1.net", 793},
            {"ntp.tuna.tsinghua.edu.cn", 794},
            {"ntp.malbolge.de", 795},
            {"78.47.234.59", 795},
            {"ntp2.roethof.net", 796},
            {"time.iqnet.com", 797},
            {"62.201.225.9", 797},
            {"auvz.com", 798},
            {"time.ostseehaie.de", 799},
            {"78.46.60.42", 799},
            {"2a01:4f8:201:4101::42", 799},
            {"ntp.giteafuntana.com", 801},
            {"ntp.syari.net", 802},
            {"91.121.165.146", 802},
            {"2001:41d0:1:e692::1", 802},
            {"suro.ubaya.ac.id", 803},
            {"173.224.213.42", 805},
            {"ntp1.tcpd.net", 807},
            {"ntp2.tcpd.net", 808},
            {"ntp3.tcpd.net", 809},
            {"ntp.carlfletcher.org", 810},
            {"ntp.mattrudge.net", 811},
            {"46.7.145.15", 811},
            {"ntp.snotboble.net", 812},
            {"ntp.initipi.sk", 814},
            {"92.245.0.16", 814},
            {"chronus.carlso.net", 815},
            {"ntp.icestarirc.org", 816},
            {"84.200.25.31", 816},
            {"2001:1608:10:30:1::3", 816},
            {"ntp.miknight.com", 817},
            {"time.awyeah.net", 818},
            {"206.125.173.30", 818},
            {"2607:f2f8:7400::4", 818},
            {"saladfingerz.co.uk", 819},
            {"ntp.jedamzik.net", 821},
            {"ntp1.innoscale.net", 823},
            {"time.hko.hk", 825},
            {"2407:8000:8001:80::8", 825},
            {"2403:5000:171:11::2", 825},
            {"ntp1.upcbiz.ro", 830},
            {"78.96.7.25", 830},
            {"ntp3.upcbiz.ro", 832},
            {"78.96.7.8", 832},
            {"ntp.pbox.org", 833},
            {"91.121.167.54", 833},
            {"2001:41d0:1:e836::1", 833},
            {"chronos.univ-montp3.fr", 834},
            {"193.52.136.2", 834},
            {"chronos2.univ-montp3.fr", 835},
            {"193.52.137.213", 835},
            {"ntp0.hochstaetter.de", 836},
            {"176.221.46.134", 836},
            {"2a00:1158:2:2d00::123", 836},
            {"199.249.223.123", 837},
            {"ntp.terwan.nl", 838},
            {"213.125.195.210", 838},
            {"2001:470:1f15:17ce::1:0", 838},
            {"a.ntp.fryxell.info", 839},
            {"109.197.193.160", 839},
            {"2001:470:cb16:a::123", 839},
            {"ntp2.301-moved.de", 840},
            {"217.144.138.234", 840},
            {"2a02:a00:1009:6202::123", 840},
            {"bbot.org", 841},
            {"ntp1.us.vetroff.net", 843},
            {"tick.teljet.net", 847},
            {"64.25.209.61", 847},
            {"2607:fc58:1:2d::2", 847},
            {"tock.teljet.net", 848},
            {"67.217.112.181", 848},
            {"2607:fc58:1:2c::2", 848},
            {"ntp4.stratum1.ru", 849},
            {"88.147.254.229", 849},
            {"2001:470:784d:fffd::7", 849},
            {"ntp.wien.diakoniewerk.at", 851},
            {"193.170.62.252", 851},
            {"time.markosyan.info", 854},
            {"ntp.spadhausen.com", 855},
            {"ntp.4network.eu", 856},
            {"ntp1.proserve.nl", 858},
            {"80.84.224.86", 858},
            {"2001:828:101:1::86:1", 858},
            {"ntp2.proserve.nl", 859},
            {"83.96.224.86", 859},
            {"2001:828:101:42::86:1", 859},
            {"212.204.198.85", 860},
            {"2001:898:2000:1a::15", 860},
            {"fw2.unixnet.dk", 863},
            {"ntp.jh1.at", 864},
            {"88.117.229.109", 864},
            {"ntp.deman.ru", 865},
            {"212.164.119.161", 865},
            {"zeit.tr-it.net", 866},
            {"ntp2.niiftri.irkutsk.ru", 867},
            {"46.254.241.75", 867},
            {"ntp1.niiftri.irkutsk.ru", 868},
            {"46.254.241.74", 868},
            {"time.sea1.cloudsingularity.net", 872},
            {"ntp0.1asiacom.net", 876},
            {"ntp1.cu.be", 877},
            {"ntp2.cu.be", 878},
            {"ntp.crashdump.fr", 879},
            {"ntp0.dhivehinet.net.mv", 880},
            {"27.114.150.10", 880},
            {"ntp1.dhivehinet.net.mv", 881},
            {"27.114.150.11", 881},
            {"ntp2.dhivehinet.net.mv", 882},
            {"27.114.150.12", 882},
            {"ntp3.dhivehinet.net.mv", 883},
            {"27.114.150.13", 883},
            {"time.dhco.org", 885},
            {"89.101.218.6", 885},
            {"scanbitntp.scanbit-data.dk", 886},
            {"85.191.98.171", 886},
            {"ntp2.sptime.se", 889},
            {"193.11.166.18", 889},
            {"2001:6b0:42:2::123", 889},
            {"193.11.166.52", 890},
            {"2001:6b0:42:4::123", 890},
            {"ntp3.sptime.se", 891},
            {"193.11.166.36", 891},
            {"2001:6b0:42:3::123", 891},
            {"ntp1.sptime.se", 892},
            {"193.11.166.2", 892},
            {"2001:6b0:42:1::123", 892},
            {"ntp.neu.edu.cn", 893},
            {"202.118.1.46", 893},
            {"202.118.1.47", 893},
            {"202.118.1.48", 893},
            {"2001:da8:9000::46", 893},
            {"2001:da8:9000::47", 893},
            {"2001:da8:9000::48", 893},
            {"time.cloudplasma.co.uk", 894},
            {"149.202.58.157", 894},
            {"vniiftri.khv.ru", 896},
            {"212.19.6.218", 896},
            {"vniiftri2.khv.ru", 897},
            {"ntp.jbheinz.com", 898},
            {"73.37.183.90", 898},
            {"ntp1.innolan.net", 900},
            {"90.184.222.114", 900},
            {"ntp2.innolan.net", 901},
            {"90.184.222.115", 901},
            {"ntp3.innolan.net", 902},
            {"192.157.248.117", 903},
            {"ntp.luna.nl", 904},
            {"217.77.132.1", 904},
            {"ntp1.xfree.com.ar", 906},
            {"ntp-badger.dyndns.info", 907},
            {"76.123.37.53", 907},
            {"time.osoal.org.nz", 911},
            {"103.239.8.22", 911},
            {"2001:4428::dc:0:0:0:22", 911},
            {"ntp.e-utp.net", 915},
            {"89.231.96.83", 915},
            {"2001:67c:21ec:1000::b", 915},
            {"2001:67c:21ec:1000::a", 915},
            {"a.time.steadfast.net", 917},
            {"208.100.4.52", 917},
            {"2607:f128:1:3::b", 917},
            {"67.202.100.50", 918},
            {"2607:f128::50", 918},
            {"c.time.steadfast.net", 919},
            {"208.100.0.228", 919},
            {"2607:f128:1:3::dd1", 919},
            {"d.time.steadfast.net", 920},
            {"e.time.steadfast.net", 921},
            {"69.162.170.4", 921},
            {"2607:f128:400:1::dd2", 921},
            {"f.time.steadfast.net", 922},
            {"ntp.hisp.no", 924},
            {"time.m18.ru", 927},
            {"ntp.net.dn.ua", 928},
            {"193.201.206.3", 928},
            {"jasper.skywolf.net", 931},
            {"ntp.1e128.com", 934},
            {"ntp.vie.datendienst.at", 935},
            {"ntp.colinbarrett.co.uk", 938},
            {"ns.al-abrarcom.com", 940},
            {"185.23.154.26", 940},
            {"109.205.112.69", 941},
            {"ntp3.mattnordhoff.com", 943},
            {"66.228.59.187", 943},
            {"2600:3c02::13:220", 943},
            {"time.as43289.net", 944},
            {"178.17.162.12", 944},
            {"178.17.160.12", 944},
            {"178.17.161.12", 944},
            {"2a00:1dc0::12", 944},
            {"2a00:1dc0:2::12", 944},
            {"2a00:1dc0:1::12", 944},
            {"ntp2.campus-rv.net", 945},
            {"193.106.144.7", 945},
            {"2a00:fc00:e000:1::7", 945},
            {"r10.net", 946},
            {"192.168.1.230", 947},
            {"ap.cagb.org", 949},
            {"time.hnsoft.co.kr", 950},
            {"time.delphi.or.kr", 951},
            {"time.nettel.cz", 960},
            {"37.187.104.44", 960},
            {"78.108.145.1", 960},
            {"80.79.25.111", 960},
            {"ntp0.catn.com", 963},
            {"87.124.126.49", 963},
            {"ntp1.ona.org", 964},
            {"206.186.121.125", 964},
            {"ntp2.ona.org", 965},
            {"206.186.121.118", 965},
            {"ntp.poweron.dk", 967},
            {"time.helux.nl", 969},
            {"ntp.canakkalefirewall.com", 971},
            {"gclock01.dupa01.burst.net", 973},
            {"gclock02.dupa01.burst.net", 974},
            {"clock01.chil01.burst.net", 975},
            {"ntp.first2know.net", 976},
            {"164.138.26.20", 976},
            {"2a02:2770:3::21a:4aff:fe06:216", 976},
            {"207.198.125.20", 977},
            {"minx.samspin.net", 978},
            {"212.7.1.131", 979},
            {"2001:1b28:1:5::131", 979},
            {"212.7.1.132", 980},
            {"2001:1b28:1:5::132", 980},
            {"bonehead.moronica.org", 981},
            {"mercury.tyler-k.me", 984},
            {"ntp.zyx.ro", 985},
            {"89.47.39.10", 985},
            {"ntp.dom1k.tk", 986},
            {"ntp-bali.hyper.net.id", 988},
            {"114.129.16.19", 988},
            {"ntpmon.dcs1.biz", 990},
            {"203.123.48.219", 990},
            {"2405:fc00::1:0:0:0:123", 990},
            {"ntp.im-www.eu", 992},
            {"ntp.hambox.fr", 993},
            {"94.23.8.212", 993},
            {"ntp.lcf.mx", 994},
            {"189.216.244.125", 994},
            {"0x.sg", 997},
            {"ntp0.heikorichter.name", 1001},
            {"ntp1.heikorichter.name", 1002},
            {"ntp2.heikorichter.name", 1003},
            {"ntp3.heikorichter.name", 1004},
            {"ns2.interactiveshades.com", 1005},
            {"ntp04.hoberg.ch", 1008},
            {"ntp02.hoberg.ch", 1009},
            {"5.45.105.11", 1009},
            {"2a03:4000:6:126a::1337", 1009},
            {"r00t.cf", 1011},
            {"jikan.ae7.st", 1013},
            {"khronos.nis.portalus.net", 1017},
            {"173.220.95.86", 1017},
            {"ching.ae7.st", 1018},
            {"time.alaskaroad.com", 1019},
            {"67.42.122.77", 1019},
            {"204.13.164.130", 1020},
            {"timestr.lonyai.com", 1024},
            {"85.25.210.112", 1024},
            {"ntp2.jimsoffice.org", 1026},
            {"ntp.kiewel-online.ch", 1028},
            {"ntp.fangfufu.co.uk", 1030},
            {"37.187.98.51", 1030},
            {"2001:41d0:a:2233::1", 1030},
            {"ntp.freestone.net", 1031},
            {"193.5.68.2", 1031},
            {"2001:67c:8:abcd::2", 1031},
            {"klockan.poliser.nu", 1033},
            {"87.237.210.147", 1033},
            {"ntp.us.v-yu.com", 1034},
            {"ntp.eu.v-yu.com", 1035},
            {"ntp.gwadar.cn", 1036},
            {"42.96.167.209", 1036},
            {"okdquick.gotdns.org", 1037},
            {"ntp01.hoberg.ch", 1039},
            {"5.45.97.157", 1039},
            {"2a03:4000:5:221::1337", 1039},
            {"user.veloxzone.com.br", 1041},
            {"ntp1.berlin-provider.de", 1042},
            {"ntp2.berlin-provider.de", 1043},
            {"ntp4.berlin-provider.de", 1044},
            {"ntp3.berlin-provider.de", 1045},
            {"ntp5.berlin-provider.de", 1046},
            {"ntp6.berlin-provider.de", 1047},
            {"ntp4.jimsoffice.org", 1049},
            {"192.168.0.1", 1050},
            {"time.ume.tubitak.gov.tr", 1056},
            {"194.27.222.5", 1056},
            {"ntp.mamalibre.com.ar", 1057},
            {"181.164.49.61", 1057},
            {"ntp.networkxxiii.de", 1059},
            {"tock.stdtime.gov.tw", 1061},
            {"211.22.103.157", 1061},
            {"watch.stdtime.gov.tw", 1062},
            {"118.163.81.63", 1062},
            {"clock.stdtime.gov.tw", 1064},
            {"211.22.103.158", 1064},
            {"tick.stdtime.gov.tw", 1065},
            {"118.163.81.62", 1065},
            {"87.253.152.191", 1067},
            {"2a01:7c8:c020:3::191", 1067},
            {"ntp.ring.nlnog.net", 1068},
            {"80.94.65.10", 1068},
            {"2a02:d28:10:3::2", 1068},
            {"ntp.citra.net.id", 1069},
            {"202.65.114.202", 1069},
            {"mail.lee-family.me.uk", 1070},
            {"88.96.199.9", 1070},
            {"201.198.247.251", 1073},
            {"cyberdc1.cybertech.com", 1076},
            {"206.108.0.131", 1077},
            {"2620:10a:800f::11", 1077},
            {"206.108.0.132", 1078},
            {"2620:10a:800f::12", 1078},
            {"hajjam.net", 1079},
            {"ntp1.hajjam.net", 1080},
            {"ntp2.hajjam.net", 1081},
            {"bolt.brockhurst.co.nz", 1082},
            {"45.33.43.222", 1082},
            {"2600:3c01::f03c:91ff:feae:ee12", 1082},
            {"is.txtfile.eu", 1083},
            {"dl8obh.users.dk0mav.as64643.de.ampr.org", 1087},
            {"68.108.190.192", 1088},
            {"tick.usshc.com", 1089},
            {"199.102.46.70", 1089},
            {"fry.helpfulhosting.net", 1090},
            {"zoidberg.helpfulhosting.net", 1091},
            {"time.atl1.cloudsingularity.net", 1092},
            {"pool.kthx.at", 1093},
            {"107.170.157.15", 1094},
            {"70.114.226.42", 1095},
            {"larsdebruin.net", 1096},
            {"ntp.x.znx.cc", 1099},
            {"118.189.177.157", 1099},
            {"thequarkworks.com", 1101},
            {"ntp.marsh.ws", 1104},
            {"servicios.santiago.utfsm.cl", 1105},
            {"www.omaserveri.info", 1106},
            {"ojab.ru", 1107},
            {"195.91.239.8", 1107},
            {"2a02:578:5002:99::2", 1107},
            {"2001:470:27:50c::2", 1107},
            {"2002:c35b:ef08::1", 1107},
            {"tock.usshc.com", 1108},
            {"199.102.46.72", 1108},
            {"ntp.mts.by", 1109},
            {"level1e.cs.unc.edu", 1110},
            {"152.2.133.52", 1110},
            {"level1f.cs.unc.edu", 1111},
            {"152.2.133.53", 1111},
            {"level1g.cs.unc.edu", 1112},
            {"152.2.133.54", 1112},
            {"level1h.cs.unc.edu", 1113},
            {"152.2.133.55", 1113},
            {"id-co.in", 1115},
            {"5.135.186.82", 1115},
            {"2001:41d0:8:c352::1", 1115},
            {"cronos.villaraton.mx", 1116},
            {"104.236.114.203", 1116},
            {"138.197.132.106", 1116},
            {"138.68.136.118", 1116},
            {"2a03:b0c0:1:a1::470:8001", 1116},
            {"2604:a880:800:10::e25:1001", 1116},
            {"2604:a880:cad:d0::333:9001", 1116},
            {"carbon.neersighted.com", 1117},
            {"oxygen.neersighted.com", 1118},
            {"hora.tucumania.com", 1119},
            {"idcoin.me", 1120},
            {"ntp.icemoonprison.com", 1121},
            {"150.101.217.196", 1121},
            {"2001:44b8:41bd:c40f::196", 1121},
            {"ntp.rleh.de", 1122},
            {"188.68.58.202", 1122},
            {"2a03:4000:6:f071::", 1122},
            {"ntp.algon.dk", 1126},
            {"212.99.233.66", 1126},
            {"time.onlydecay.co.uk", 1130},
            {"ntp1.musurit.net", 1132},
            {"131.0.232.2", 1132},
            {"2803:f580::2", 1132},
            {"ntp.intiland.net", 1133},
            {"113.52.148.37", 1133},
            {"2001:df0:e2:5::37", 1133},
            {"time.ian.sh", 1134},
            {"31.214.242.211", 1135},
            {"108.224.49.4", 1136},
            {"77.37.146.85", 1138},
            {"ntp2.ir.mihanit.net", 1139},
            {"ntp1.versadns.com", 1140},
            {"50.126.194.189", 1140},
            {"ntp2a.versadns.com", 1141},
            {"69.60.110.177", 1141},
            {"ntp.vortex.tillo.ch", 1142},
            {"31.3.135.238", 1142},
            {"ntp.twafamkes.nl", 1145},
            {"82.95.77.234", 1145},
            {"2001:980:1419:1:ba27:ebff:fe1b:14a5", 1145},
            {"ntp.oalm.gub.uy", 1146},
            {"190.64.208.2", 1146},
            {"195.154.71.176", 1150},
            {"0.time.itoc.com.au", 1153},
            {"54.206.109.187", 1153},
            {"h9913310.innovit-it.nl", 1154},
            {"vieth-server.de", 1155},
            {"pfuideifi.org", 1156},
            {"ntp0.a-schieb.de", 1160},
            {"ntp1.a-schieb.de", 1161},
            {"ntp.bytenet.in", 1162},
            {"t96.nl", 1163},
            {"ntp1.xipalia.com", 1167},
            {"37.59.119.229", 1167},
            {"ntp2.xipalia.com", 1168},
            {"85.25.49.90", 1168},
            {"ntp03.hoberg.ch", 1170},
            {"2a03:4000:5:221::1338", 1170},
            {"onion.huggyshifters.co.uk", 1171},
            {"ntp.dystopia.io", 1172},
            {"108.52.219.144", 1172},
            {"ntp.mobatime.ru", 1173},
            {"85.114.26.194", 1173},
            {"ntp1.tsahosting.net", 1174},
            {"72.67.6.35", 1174},
            {"ntp2.tsahosting.net", 1175},
            {"ntp6.smatwebdesign.com", 1177},
            {"2600:3c00::f03c:91ff:fe18:b0dc", 1177},
            {"ntp.fizyka.umk.pl", 1178},
            {"158.75.5.245", 1178},
            {"time.server02.sm-ict.com", 1179},
            {"ifconfig.com.ua", 1180},
            {"78.26.180.80", 1180},
            {"ntp0.borg-collective.org.uk", 1181},
            {"192.81.223.51", 1181},
            {"ntp0.goonhillydatacentre.co.uk", 1182},
            {"ntp-de.stygium.net", 1183},
            {"104.238.159.77", 1183},
            {"2001:19f0:6c00:94c6:5400:ff:fe16:b301", 1183},
            {"izz.ntp.org", 1184},
            {"ntp1.atabyte.net", 1185},
            {"208.100.29.180", 1185},
            {"2607:f128:40:2a00:a576::", 1185},
            {"ntp2.atabyte.net", 1186},
            {"ntp01.steambay.nl", 1187},
            {"ntp02.steambay.nl", 1188},
            {"ntp03.steambay.nl", 1189},
            {"ntp1a.versadns.com", 1190},
            {"50.4.23.100", 1190},
            {"time.fotiu.com", 1191},
            {"69.90.132.51", 1191},
            {"93.157.10.210", 1192},
            {"ntp.rootshells.eu", 1193},
            {"83.162.251.130", 1194},
            {"2001:981:fc90:1::1618", 1194},
            {"ntp2.viertwaalf.nl", 1195},
            {"ntp1.flarecloud.net", 1196},
            {"54.83.7.186", 1196},
            {"ntp1.xe.gr", 1198},
            {"194.116.168.40", 1198},
            {"ntp2.xe.gr", 1199},
            {"194.116.168.41", 1199},
            {"ntp2.crifo.org", 1200},
            {"163.172.198.88", 1200},
            {"ntp.silicann.com", 1201},
            {"88.80.200.13", 1201},
            {"213.231.5.165", 1202},
            {"194.54.161.214", 1203},
            {"78.26.180.56", 1204},
            {"206.108.0.133", 1205},
            {"2620:10a:800f::13", 1205},
            {"time1.bokke.rs", 1206},
            {"84.80.85.74", 1206},
            {"2001:470:1f15:110e:87d:2d0d:5d64:7da8", 1206},
            {"time.optimaal.fm", 1207},
            {"0.ntp.2rz.ru", 1208},
            {"85.116.124.104", 1208},
            {"kangaroo.lan.forstwoof.ru", 1209},
            {"213.141.154.170", 1209},
            {"2001:470:733c:1::5", 1209},
            {"chameleon.forstwoof.ru", 1210},
            {"time.jo", 1211},
            {"ntp.jo", 1213},
            {"ntp1.teambelgium.net", 1217},
            {"81.83.19.45", 1217},
            {"2a02:1807:10::1", 1217},
            {"62.168.116.66", 1220},
            {"ntp0.dc1.laodc.com", 1221},
            {"ntp.stevemeacham.net", 1222},
            {"50.116.52.97", 1222},
            {"2600:3c03::f03c:91ff:feae:82c1", 1222},
            {"192.168.129.212", 1223},
            {"fe80::f03c:91ff:feae:82c1", 1223},
            {"ntp1.anduin.org.uk", 1224},
            {"92.27.75.51", 1224},
            {"2001:470:1f09:a8e::3", 1224},
            {"ntp.omnilance.com", 1226},
            {"194.54.80.28", 1226},
            {"2001:67c:25dc::10", 1226},
            {"193.145.15.6", 1228},
            {"dcmainut01.srsmain.com", 1231},
            {"cambria.bitsrc.net", 1232},
            {"69.64.225.2", 1232},
            {"ntp1.laukas.lt", 1233},
            {"78.60.205.220", 1233},
            {"time.jlkhosting.com", 1234},
            {"167.114.204.238", 1234},
            {"ntp.jre655.com", 1235},
            {"157.7.208.12", 1235},
            {"ntp.neusoft.edu.cn", 1237},
            {"219.216.128.25", 1237},
            {"2001:da8:a807::25", 1237},
            {"nettuno.ntp.irh.it", 1239},
            {"37.247.53.178", 1239},
            {"2a00:dcc0:dead:a5b2::123", 1239},
            {"ntp.finalhosting.cz", 1240},
            {"46.167.244.222", 1240},
            {"lumberton-nj-ntp.dyndns.info", 1241},
            {"71.188.120.163", 1241},
            {"17ctuxuong.nsupdate.org", 1242},
            {"time.btr.net", 1243},
            {"45.79.182.100", 1243},
            {"2600:3c03::f03c:91ff:fe61:c5a3", 1243},
            {"ntp.cure.edu.uy", 1245},
            {"164.73.227.4", 1245},
            {"2001:1328:56::4", 1245},
            {"ntp.copayan.uy", 1246},
            {"190.64.134.52", 1246},
            {"ntp2.cure.edu.uy", 1247},
            {"164.73.232.34", 1247},
            {"minuto.roa.es", 1248},
            {"150.214.94.10", 1248},
            {"ntp.civix.ci", 1250},
            {"ntp.looney.network", 1252},
            {"83.162.149.224", 1252},
            {"time0.raxacoricofallapatorius.biz", 1253},
            {"82.69.171.134", 1253},
            {"time1.raxacoricofallapatorius.biz", 1255},
            {"82.69.193.46", 1255},
            {"ntp.sstf.nsk.ru", 1256},
            {"80.242.83.227", 1256},
            {"ntp.bcs2005.de", 1257},
            {"ntp.neo.consult-in.fr", 1258},
            {"time.t3kkit.com", 1260},
            {"86.85.103.243", 1260},
            {"stratum-1.sjc02.svwh.net", 1261},
            {"162.213.2.253", 1261},
            {"ntp.bcs2005.net", 1262},
            {"time1.mbix.ca", 1263},
            {"198.181.199.82", 1263},
            {"2620:19:4000:100::82", 1263},
            {"jarvis.arlen.io", 1266},
            {"45.33.13.54", 1266},
            {"2600:3c00:e000:143::5", 1266},
            {"domser.atomki.mta.hu", 1267},
            {"193.6.176.19", 1267},
            {"2001:738:3100:310:13::", 1267},
            {"ntp.atomki.mta.hu", 1268},
            {"193.6.176.59", 1268},
            {"learning.raf.edu.rs", 1269},
            {"217.24.20.5", 1269},
            {"2001:470:2160:1:20c:29ff:fe28:be8d", 1269},
            {"ntp.nexcess.net", 1270},
            {"208.69.120.241", 1270},
            {"2607:f7c0:1:af00:d045:7800::f1", 1270},
            {"ntp.sdi.net.id", 1271},
            {"0.ntp.segoen.ml", 1272},
            {"time.nc7j.com", 1274},
            {"73.98.218.154", 1274},
            {"168.181.185.90", 1275},
            {"ntp.mirror.ba", 1276},
            {"80.65.85.94", 1276},
            {"52.29.252.68", 1277},
            {"us.ut.time1.ntp.jvwjgames.net", 1278},
            {"ntp.intergnet.ru", 1279},
            {"91.211.136.1", 1279},
            {"mail.mountaintop.org", 1280},
            {"24.111.6.130", 1280},
            {"tick.pdp.bz", 1285},
            {"91.134.227.50", 1285},
            {"2001:470:1a04::91:134:227:50", 1285},
            {"tock.pdp.bz", 1286},
            {"91.134.227.51", 1286},
            {"2001:470:1a04::91:134:227:51", 1286},
            {"rjbeilstein.org", 1287},
            {"71.176.109.169", 1287},
            {"roc.nipne.ro", 1291},
            {"194.102.58.173", 1291},
            {"0x21h.net", 1292},
            {"82.193.117.90", 1292},
            {"2001:15c0:65ff:235::2", 1292},
            {"ntp.thaidns.co.th", 1294},
            {"202.129.206.95", 1294},
            {"pool.time.org", 1295},
            {"time.coreblock.io", 1296},
            {"139.59.177.198", 1296},
            {"2a03:b0c0:1:a1::470:5001", 1296},
            {"ntp.oticasvisao.net.br", 1297},
            {"me-ntp.mecc.edu", 1298},
            {"sanyalnet-cloud-vps.freeddns.org", 1302},
            {"64.137.248.161", 1302},
            {"64.137.248.212", 1302},
            {"sanyalnet-cloud-vps2.freeddns.org", 1304},
            {"64.137.228.122", 1304},
            {"ntp2.ic.net.uk", 1308},
            {"193.188.205.101", 1308},
            {"2a02:ac00:2:1::5", 1308},
            {"ntp1.franconet.ca", 1309},
            {"time.dunitek.com", 1312},
            {"192.187.114.131", 1312},
            {"www.simonbarjona.com", 1313},
            {"23.31.92.161", 1313},
            {"second.jerpat.us", 1314},
            {"certic.info", 1315},
            {"31.193.170.5", 1315},
            {"time.esa.int", 1317},
            {"131.176.107.13", 1317}
        };
    }
}